==> ejc-middlemeasurement-impl-3.0.0-20221123.065221-240-sources.jar: com/ejianc/business/middlemeasurement/bean/SubcontractingvolumeodetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包报量报告其他扣款子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_subcontractingvolumeodetail")
public class SubcontractingvolumeodetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="expense_name")
    private java.lang.String expenseName; // 费用名称
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="o_quantity")
    private java.math.BigDecimal oQuantity; // 数量
    @TableField(value="o_unit_price")
    private java.math.BigDecimal oUnitPrice; // 单价
    @TableField(value="amounts")
    private java.math.BigDecimal amounts; // 金额
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="withholding_other")
    private java.lang.String withholdingOther; //其他扣款/代扣款

    public String getWithholdingOther() {
        return withholdingOther;
    }

    public void setWithholdingOther(String withholdingOther) {
        this.withholdingOther = withholdingOther;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 费用名称
     */
    public java.lang.String getExpenseName() {
        return expenseName;
    }

    /**
     * 费用名称
     */
    public void setExpenseName(java.lang.String expenseName) {
        this.expenseName = expenseName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }

    public BigDecimal getoQuantity() {
        return oQuantity;
    }

    public void setoQuantity(BigDecimal oQuantity) {
        this.oQuantity = oQuantity;
    }

    public BigDecimal getoUnitPrice() {
        return oUnitPrice;
    }

    public void setoUnitPrice(BigDecimal oUnitPrice) {
        this.oUnitPrice = oUnitPrice;
    }

    /**
     * 金额
     */
    public java.math.BigDecimal getAmounts() {
        return amounts;
    }

    /**
     * 金额
     */
    public void setAmounts(java.math.BigDecimal amounts) {
        this.amounts = amounts;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-middlemeasurement-impl-3.0.0-20221210.113221-276-sources.jar: com/ejianc/business/middlemeasurement/bean/SubcontractingvolumeodetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包报量报告其他扣款子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_subcontractingvolumeodetail")
public class SubcontractingvolumeodetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="expense_name")
    private java.lang.String expenseName; // 费用名称
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="o_quantity")
    private java.math.BigDecimal oQuantity; // 数量
    @TableField(value="o_unit_price")
    private java.math.BigDecimal oUnitPrice; // 单价
    @TableField(value="amounts")
    private java.math.BigDecimal amounts; // 金额
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="withholding_other")
    private java.lang.String withholdingOther; //其他扣款/代扣款
    @TableField(value="o_unit_tax_price")
    private BigDecimal oUnitTaxPrice; //单价(含税)
    @TableField(value="tax_amounts")
    private BigDecimal taxAmounts; //金额(含税)

    public String getWithholdingOther() {
        return withholdingOther;
    }

    public void setWithholdingOther(String withholdingOther) {
        this.withholdingOther = withholdingOther;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 费用名称
     */
    public java.lang.String getExpenseName() {
        return expenseName;
    }

    /**
     * 费用名称
     */
    public void setExpenseName(java.lang.String expenseName) {
        this.expenseName = expenseName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }

    public BigDecimal getoQuantity() {
        return oQuantity;
    }

    public void setoQuantity(BigDecimal oQuantity) {
        this.oQuantity = oQuantity;
    }

    public BigDecimal getoUnitPrice() {
        return oUnitPrice;
    }

    public void setoUnitPrice(BigDecimal oUnitPrice) {
        this.oUnitPrice = oUnitPrice;
    }

    /**
     * 金额
     */
    public java.math.BigDecimal getAmounts() {
        return amounts;
    }

    /**
     * 金额
     */
    public void setAmounts(java.math.BigDecimal amounts) {
        this.amounts = amounts;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public BigDecimal getoUnitTaxPrice() {
        return oUnitTaxPrice;
    }

    public void setoUnitTaxPrice(BigDecimal oUnitTaxPrice) {
        this.oUnitTaxPrice = oUnitTaxPrice;
    }

    public BigDecimal getTaxAmounts() {
        return taxAmounts;
    }

    public void setTaxAmounts(BigDecimal taxAmounts) {
        this.taxAmounts = taxAmounts;
    }
}
